@@ -32,12 +32,13 @@
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mc-protocol.h>
 
-#include <libempathy/empathy-debug.h>
+#include <libempathy/empathy-utils.h>
 
 #include "empathy-account-widget.h"
 #include "empathy-ui-utils.h"
 
-#define DEBUG_DOMAIN "AccountWidget"
+#define DEBUG_FLAG EMPATHY_DEBUG_ACCOUNT
+#include <libempathy/empathy-debug.h>
 
 static gboolean 
 account_widget_entry_focus_cb (GtkWidget     *widget,
@@ -55,12 +56,31 @@ account_widget_entry_focus_cb (GtkWidget     *widget,
 
 		mc_account_unset_param (account, param_name);
 		mc_account_get_param_string (account, param_name, &value);
-		empathy_debug (DEBUG_DOMAIN, "Unset %s and restore to %s", param_name, value);
+		DEBUG ("Unset %s and restore to %s", param_name, value);
 		gtk_entry_set_text (GTK_ENTRY (widget), value ? value : "");
 		g_free (value);
 	} else {
-		empathy_debug (DEBUG_DOMAIN, "Setting %s to %s", param_name, str);
+		McProfile   *profile;
+		const gchar *domain = NULL;
+		gchar       *dup_str = NULL;
+
+		profile = mc_account_get_profile (account);
+		if (mc_profile_get_capabilities (profile) &
+		    MC_PROFILE_CAPABILITY_SPLIT_ACCOUNT) {
+			domain = mc_profile_get_default_account_domain (profile);
+		}
+
+		if (domain && !strstr (str, "@") &&
+		    strcmp (param_name, "account") == 0) {
+			DEBUG ("Adding @%s suffix to account", domain);
+			str = dup_str = g_strconcat (str, "@", domain, NULL);
+			gtk_entry_set_text (GTK_ENTRY (widget), str);
+		}
+		DEBUG ("Setting %s to %s", param_name,
+			strstr (param_name, "password") ? "***" : str);
 		mc_account_set_param_string (account, param_name, str);
+		g_free (dup_str);
+		g_object_unref (profile);
 	}
 
 	return FALSE;
@@ -79,10 +99,10 @@ account_widget_int_changed_cb (GtkWidget *widget,
 	if (value == 0) {
 		mc_account_unset_param (account, param_name);
 		mc_account_get_param_int (account, param_name, &value);
-		empathy_debug (DEBUG_DOMAIN, "Unset %s and restore to %d", param_name, value);
+		DEBUG ("Unset %s and restore to %d", param_name, value);
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value);
 	} else {
-		empathy_debug (DEBUG_DOMAIN, "Setting %s to %d", param_name, value);
+		DEBUG ("Setting %s to %d", param_name, value);
 		mc_account_set_param_int (account, param_name, value);
 	}
 }
@@ -105,9 +125,9 @@ account_widget_checkbutton_toggled_cb (GtkWidget *widget,
 	mc_account_get_param_boolean (account, param_name, &default_value);
 
 	if (default_value == value) {
-		empathy_debug (DEBUG_DOMAIN, "Unset %s and restore to %d", param_name, default_value);
+		DEBUG ("Unset %s and restore to %d", param_name, default_value);
 	} else {
-		empathy_debug (DEBUG_DOMAIN, "Setting %s to %d", param_name, value);
+		DEBUG ("Setting %s to %d", param_name, value);
 		mc_account_set_param_boolean (account, param_name, value);
 	}
 }
@@ -122,7 +142,7 @@ account_widget_forget_clicked_cb (GtkWidget *button,
 	param_name = g_object_get_data (G_OBJECT (entry), "param_name");
 	account = g_object_get_data (G_OBJECT (entry), "account");
 
-	empathy_debug (DEBUG_DOMAIN, "Unset %s", param_name);
+	DEBUG ("Unset %s", param_name);
 	mc_account_unset_param (account, param_name);
 	gtk_entry_set_text (GTK_ENTRY (entry), "");
 }
@@ -207,9 +227,7 @@ account_widget_setup_widget (GtkWidget   *widget,
 				  G_CALLBACK (account_widget_checkbutton_toggled_cb),
 				  account);
 	} else {
-		empathy_debug (DEBUG_DOMAIN,
-		               "Unknown type of widget for param %s",
-		               param_name);
+		DEBUG ("Unknown type of widget for param %s", param_name);
 	}
 }
 
@@ -355,9 +373,8 @@ accounts_widget_generic_setup (McAccount *account,
 					  GTK_FILL | GTK_EXPAND, 0,
 					  0, 0);
 		} else {
-			empathy_debug (DEBUG_DOMAIN,
-				       "Unknown signature for param %s: %s",
-				       param_name_formatted, param->signature);
+			DEBUG ("Unknown signature for param %s: %s",
+				param_name_formatted, param->signature);
 		}
 
 		if (widget) {
@@ -446,16 +463,20 @@ empathy_account_widget_generic_new (McAccount *account)
 	GtkWidget *widget;
 	GtkWidget *table_common_settings;
 	GtkWidget *table_advanced_settings;
+	gchar     *filename;
 
 	g_return_val_if_fail (MC_IS_ACCOUNT (account), NULL);
 
-	glade = empathy_glade_get_file ("empathy-account-widget-generic.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-generic.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 					"vbox_generic_settings",
 					NULL,
 					"vbox_generic_settings", &widget,
 					"table_common_settings", &table_common_settings,
 					"table_advanced_settings", &table_advanced_settings,
 					NULL);
+	g_free (filename);
 
 	accounts_widget_generic_setup (account, table_common_settings, table_advanced_settings);
 
@@ -471,12 +492,16 @@ empathy_account_widget_salut_new (McAccount *account)
 {
 	GladeXML  *glade;
 	GtkWidget *widget;
+	gchar     *filename;
 
-	glade = empathy_glade_get_file ("empathy-account-widget-salut.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-salut.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 					"vbox_salut_settings",
 					NULL,
 					"vbox_salut_settings", &widget,
 					NULL);
+	g_free (filename);
 
 	empathy_account_widget_handle_params (account, glade,
 			"entry_published", "published-name",
@@ -499,12 +524,16 @@ empathy_account_widget_msn_new (McAccount *account)
 {
 	GladeXML  *glade;
 	GtkWidget *widget;
+	gchar     *filename;
 
-	glade = empathy_glade_get_file ("empathy-account-widget-msn.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-msn.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 					"vbox_msn_settings",
 					NULL,
 					"vbox_msn_settings", &widget,
 					NULL);
+	g_free (filename);
 
 	empathy_account_widget_handle_params (account, glade,
 			"entry_id", "account",
@@ -524,49 +553,6 @@ empathy_account_widget_msn_new (McAccount *account)
 	return widget;
 }
 
-GtkWidget *
-empathy_account_widget_sip_new (McAccount *account)
-{
-	GladeXML  *glade;
-	GtkWidget *widget;
-
-	glade = empathy_glade_get_file ("empathy-account-widget-sip.glade",
-					"vbox_sip_settings",
-					NULL,
-					"vbox_sip_settings", &widget,
-					NULL);
-
-	empathy_account_widget_handle_params (account, glade,
-		"entry_userid", "account",
-		"entry_password", "password",
-		"entry_registar", "registar",
-		"entry_proxy","proxy-host",
-		"spinbutton_port", "port",
-		"entry_transport", "transport",
-		"checkbutton_discover-binding","discover-binding",
-		"entry_keepalive-mechanism", "keepalive-mechanism",
-		"entry_keepalive-interval", "keepalive-interval",
-		"checkbutton_discover-stun", "discover-stun",
-		"entry_stun-server", "stun-server",
-		"spinbutton_stun-port", "stun-port",
-		"entry_local-ip", "local-ip-address",
-		"spinbutton_local-port", "local-port",
-		"entry_extra-auth-user", "extra-auth-user",
-		"entry_extra-auth-password", "extra-auth-password",
-		"checkbutton_avoid-difficult", "avoid-difficult",
-		NULL);
-
-	empathy_account_widget_add_forget_button (account, glade,
-						  "button_forget",
-						  "entry_password");
-
-	g_object_unref (glade);
-
-	gtk_widget_show (widget);
-
-	return widget;
-}
-
 GtkWidget *
 empathy_account_widget_jabber_new (McAccount *account)
 {
@@ -574,14 +560,18 @@ empathy_account_widget_jabber_new (McAccount *account)
 	GtkWidget *widget;
 	GtkWidget *spinbutton_port;
 	GtkWidget *checkbutton_ssl;
+	gchar     *filename;
 
-	glade = empathy_glade_get_file ("empathy-account-widget-jabber.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-jabber.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 				        "vbox_jabber_settings",
 				        NULL,
 				        "vbox_jabber_settings", &widget,
 				        "spinbutton_port", &spinbutton_port,
 				        "checkbutton_ssl", &checkbutton_ssl,
 				        NULL);
+	g_free (filename);
 
 	empathy_account_widget_handle_params (account, glade,
 			"entry_id", "account",
@@ -616,13 +606,17 @@ empathy_account_widget_icq_new (McAccount *account)
 	GladeXML  *glade;
 	GtkWidget *widget;
 	GtkWidget *spinbutton_port;
+	gchar     *filename;
 
-	glade = empathy_glade_get_file ("empathy-account-widget-icq.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-icq.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 				        "vbox_icq_settings",
 				        NULL,
 				        "vbox_icq_settings", &widget,
 				        "spinbutton_port", &spinbutton_port,
 				        NULL);
+	g_free (filename);
 
 	empathy_account_widget_handle_params (account, glade,
 			"entry_uin", "account",
@@ -643,17 +637,57 @@ empathy_account_widget_icq_new (McAccount *account)
 	return widget;
 }
 
+GtkWidget *
+empathy_account_widget_aim_new (McAccount *account)
+{
+	GladeXML  *glade;
+	GtkWidget *widget;
+	GtkWidget *spinbutton_port;
+	gchar     *filename;
+
+	filename = empathy_file_lookup ("empathy-account-widget-aim.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
+				        "vbox_aim_settings",
+				        NULL,
+				        "vbox_aim_settings", &widget,
+				        "spinbutton_port", &spinbutton_port,
+				        NULL);
+	g_free (filename);
+
+	empathy_account_widget_handle_params (account, glade,
+			"entry_screenname", "account",
+			"entry_password", "password",
+			"entry_server", "server",
+			"spinbutton_port", "port",
+			NULL);
+
+	empathy_account_widget_add_forget_button (account, glade,
+						  "button_forget",
+						  "entry_password");
+
+	g_object_unref (glade);
+
+	gtk_widget_show (widget);
+
+	return widget;
+}
+
 GtkWidget *
 empathy_account_widget_yahoo_new (McAccount *account)
 {
 	GladeXML  *glade;
 	GtkWidget *widget;
+	gchar     *filename;
 
-	glade = empathy_glade_get_file ("empathy-account-widget-yahoo.glade",
+	filename = empathy_file_lookup ("empathy-account-widget-yahoo.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
 					"vbox_yahoo_settings",
 					NULL,
 					"vbox_yahoo_settings", &widget,
 					NULL);
+	g_free (filename);
 
 	empathy_account_widget_handle_params (account, glade,
 			"entry_id", "account",
@@ -678,3 +712,37 @@ empathy_account_widget_yahoo_new (McAccount *account)
 	return widget;
 }
 
+GtkWidget *
+empathy_account_widget_groupwise_new (McAccount *account)
+{
+	GladeXML  *glade;
+	GtkWidget *widget;
+	gchar     *filename;
+
+	filename = empathy_file_lookup ("empathy-account-widget-groupwise.glade",
+					"libempathy-gtk");
+	glade = empathy_glade_get_file (filename,
+					"vbox_groupwise_settings",
+					NULL,
+					"vbox_groupwise_settings", &widget,
+					NULL);
+	g_free (filename);
+
+	empathy_account_widget_handle_params (account, glade,
+			"entry_id", "account",
+			"entry_password", "password",
+			"entry_server", "server",
+			"spinbutton_port", "port",
+			NULL);
+
+	empathy_account_widget_add_forget_button (account, glade,
+						  "button_forget",
+						  "entry_password");
+
+	g_object_unref (glade);
+
+	gtk_widget_show (widget);
+
+	return widget;
+}
+
