@@ -1294,13 +1294,17 @@ empathy_get_toplevel_window (GtkWidget *widget)
 static gchar *
 fixup_url (const gchar *url)
 {
-	if (!g_str_has_prefix (url, "ghelp:") &&
-	    !strstr (url, ":/") &&
-	    !strstr (url, "@")) {
-		return g_strdup_printf ("http://%s", url);
-	} else {
+	if (g_str_has_prefix (url, "ghelp:") ||
+	    g_str_has_prefix (url, "mailto:") ||
+	    strstr (url, ":/")) {
 		return NULL;
 	}
+
+	if (strstr (url, "@")) {
+		return g_strdup_printf ("mailto:%s", url);
+	}
+
+	return g_strdup_printf ("http://%s", url);
 }
 
 void
@@ -1325,7 +1329,7 @@ empathy_url_show (const char *url)
 						 GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, 
 						 _("Unable to open URI"));
 		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-							  error->message);
+							  "%s", error->message);
 
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (gtk_widget_destroy),
