@@ -100,6 +100,8 @@ dispatch_channel_cb (EmpathyDispatcher *dispatcher,
 	else if (!tp_strdiff (channel_type, TP_IFACE_CHANNEL_TYPE_STREAMED_MEDIA)) {
 		empathy_call_window_new (channel);
 	}
+
+	g_free (channel_type);
 }
 
 static void
@@ -358,12 +360,17 @@ main (int argc, char *argv[])
 	EmpathyIdle       *idle;
 	gboolean           autoconnect = TRUE;
 	gboolean           no_connect = FALSE; 
+	gboolean           hide_contact_list = FALSE;
 	GError            *error = NULL;
 	GOptionEntry       options[] = {
 		{ "no-connect", 'n',
 		  0, G_OPTION_ARG_NONE, &no_connect,
 		  N_("Don't connect on startup"),
 		  NULL },
+		{ "hide-contact-list", 'h',
+		  0, G_OPTION_ARG_NONE, &hide_contact_list,
+		  N_("Don't show the contact list on startup"),
+		  NULL },
 		{ NULL }
 	};
 
@@ -446,7 +453,7 @@ main (int argc, char *argv[])
 
 	/* Setting up UI */
 	window = empathy_main_window_show ();
-	icon = empathy_status_icon_new (GTK_WINDOW (window));
+	icon = empathy_status_icon_new (GTK_WINDOW (window), hide_contact_list);
 
 	if (connection) {
 		/* We se the callback here because we need window */
