@@ -22,7 +22,7 @@ main (int argc, char **argv)
 	main_loop = g_main_loop_new (NULL, FALSE);
 	manager = empathy_contact_manager_new ();
 
-	g_timeout_add (5000, time_out, main_loop);
+	g_timeout_add_seconds (5, time_out, main_loop);
 
 	g_main_loop_run (main_loop);
 
